@@ -8,19 +8,39 @@ Currently available commands are::
     controller, shell
 """
 import os
-import os.path
 import sys
-import glob
 import pylons
 import pylons.util as util
 
 from paste.script.command import Command, BadCommand
 from paste.script.filemaker import FileOp
-from paste.script import pluginlib, copydir
 from paste.deploy import loadapp, appconfig
 import paste.deploy.config
 import paste.fixture
 
+def validate_name(name):
+    """Validate that the name for the controller isn't present on the
+    path already"""
+    if not name:
+        # This happens when the name is an existing directory
+        raise BadCommand('Please give the name of a controller.')
+    try:
+        __import__(name)
+        raise BadCommand(
+            "\n\nA module named '%s' is already present in your "
+            "PYTHON_PATH.\n Choosing a conflicting name will likely cause"
+            " import problems in\n your controller at some point. It's "
+            "suggested that you choose an alternate\nname, and if you'd "
+            "like that name to be accessible as '%s', add a route\n"
+            "to your projects config/routing.py file similar to:\n"
+            "  map.connect('%s', controller='my_%s')" \
+            % (name, name, name, name))
+    except ImportError:
+        # This is actually the result we want
+        pass
+    
+    return True
+
 class ControllerCommand(Command):
     """Create a Controller and functional test for it
     
@@ -41,7 +61,6 @@ class ControllerCommand(Command):
         Creating yourproj/controllers/admin
         Creating yourproj/yourproj/controllers/admin/trackback.py
         Creating yourproj/yourproj/tests/functional/test_admin_trackback.py
-    
     """
     summary = __doc__
     usage = 'CONTROLLER_NAME'
@@ -57,51 +76,37 @@ class ControllerCommand(Command):
                       action='store_true',
                       dest='no_test',
                       help="Don't create the test; just the controller")
-    
-    def validate_name(self, name):
-        if not name:
-            # This happens when the name is an existing directory
-            raise BadCommand('Please give the name of a controller.')
-        try:
-            __import__(name)
-            raise BadCommand("\n\nA module named '%s' is already present in your PYTHON_PATH.\n"
-                             "Choosing a conflicting name will likely cause import problems in\n"
-                             "your controller at some point. It's suggested that you choose an alternate\n"
-                             "name, and if you'd like that name to be accessible as '%s', add a route\n"
-                             "to your projects config/routing.py file similar to:\n"
-                             "  map.connect('%s', controller='my_%s')" % (name, name, name, name))
-        except ImportError:
-            # This is actually the result we want
-            pass
-        
-        return True
-        
+            
     def command(self):
+        """Main command to create controller"""
         try:
-            fo = FileOp(source_dir=os.path.join(os.path.dirname(__file__), 'templates'))
+            file_op = FileOp(source_dir=os.path.join(
+                os.path.dirname(__file__), 'templates'))
             try:
-                name, dir = fo.parse_path_name_args(self.args[0])
+                name, directory = file_op.parse_path_name_args(self.args[0])
             except:
                 raise BadCommand('No egg_info directory was found')
             
             # Validate the name
             name = name.replace('-', '_')
-            self.validate_name(name)
+            validate_name(name)
             
-            fullname = os.path.join(dir, name)
-            controller_name = util.class_name_from_module_name(name.split('/')[-1])
-            if not fullname.startswith(os.sep): fullname = os.sep + fullname
+            fullname = os.path.join(directory, name)
+            controller_name = util.class_name_from_module_name(
+                name.split('/')[-1])
+            if not fullname.startswith(os.sep):
+                fullname = os.sep + fullname
             testname = fullname.replace(os.sep, '_')[1:]
-            fo.template_vars.update({'name': controller_name,
-                                  'fname': os.path.join(dir, name)})
-            fo.copy_file(template='controller.py_tmpl',
-                         dest=os.path.join('controllers', dir), filename=name)
+            file_op.template_vars.update({'name': controller_name,
+                                  'fname': os.path.join(directory, name)})
+            file_op.copy_file(template='controller.py_tmpl',
+                         dest=os.path.join('controllers', directory), 
+                         filename=name)
             if not self.options.no_test:
-                fo.copy_file(template='test_controller.py_tmpl',
+                file_op.copy_file(template='test_controller.py_tmpl',
                              dest=os.path.join('tests', 'functional'),
                              filename='test_'+testname)
         except:
-            import sys
             msg = str(sys.exc_info()[1])
             raise BadCommand('An unknown error ocurred, %s' % msg)
 
@@ -128,6 +133,7 @@ class ShellCommand(Command):
     parser = Command.standard_parser(simulate=True)
 
     def command(self):
+        """Main command to create a new shell"""
         self.verbose = 3
         
         if len(self.args) == 0:
@@ -169,9 +175,9 @@ class ShellCommand(Command):
         make_map = getattr(sys.modules[routing_package], 'make_map')
         mapper = make_map()
         test_app = app=paste.fixture.TestApp(wsgiapp)
-        g = None
+        global_obj = None
         try:
-            g = test_app.get('/').g
+            global_obj = test_app.get('/').g
         except:
             pass
         
@@ -184,45 +190,58 @@ class ShellCommand(Command):
                 h=sys.modules[helpers_package],
             )
         )
-        if g:
-            locs['g'] = g
-            pylons.g.push_object(g)
+        if global_obj:
+            locs['g'] = global_obj
+            pylons.g.push_object(global_obj)
         
         banner = "Pylons Interactive Shell\nPython %s\n\n" % sys.version
         banner += "Additional Objects:\n"
         banner += "  %-10s -  %s\n" % ('mapper', 'Routes mapper object')
         banner += "  %-10s -  %s\n" % ('h', 'Helper object')
-        if g:
+        if global_obj:
             banner += "  %-10s -  %s\n" % ('g', 'Globals object')
         banner += "  %-10s -  %s\n" % ('model', 'Models from models package')
-        banner += "  %-10s -  %s\n" % ('wsgiapp', 'This projects WSGI App instance')
-        banner += "  %-10s -  %s\n" % ('app', 'paste.fixture wrapped around wsgiapp')
+        banner += "  %-10s -  %s\n" % ('wsgiapp', 
+            'This projects WSGI App instance')
+        banner += "  %-10s -  %s\n" % ('app', 
+            'paste.fixture wrapped around wsgiapp')
         try:
             # try to use IPython if possible
             import IPython
         
             class CustomIPShell(IPython.iplib.InteractiveShell):
+                """Custom shell class to handle raw input"""
                 def raw_input(self, *args, **kw):
+                    """Capture raw input in exception wrapping"""
                     try:
-                        return IPython.iplib.InteractiveShell.raw_input(self, *args, **kw)
+                        return IPython.iplib.InteractiveShell.raw_input(
+                            self, *args, **kw)
                     except EOFError:
-                        # In the future, we'll put our own override as needed to save
-                        # models, TG style
+                        # In the future, we'll put our own override as needed 
+                        # to save models, TG style
                         raise EOFError
 
-            shell = IPython.Shell.IPShell(user_ns=locs, shell_class=CustomIPShell)
+            shell = IPython.Shell.IPShell(user_ns=locs, 
+                shell_class=CustomIPShell)
             shell.mainloop()
         except ImportError:
             import code
             
             class CustomShell(code.InteractiveConsole):
+                """Custom shell class to handle raw input"""
                 def raw_input(self, *args, **kw):
+                    """Capture raw input in exception wrapping"""
                     try:
-                        return code.InteractiveConsole.raw_input(self, *args, **kw)
+                        return code.InteractiveConsole.raw_input(
+                            self, *args, **kw)
                     except EOFError:
-                        # In the future, we'll put our own override as needed to save
-                        # models, TG style
+                        # In the future, we'll put our own override as needed 
+                        # to save models, TG style
                         raise EOFError
             
             shell = CustomShell(locals=locs)
+            try:
+                import readline
+            except ImportError:
+                pass
             shell.interact(banner)
