@@ -48,10 +48,9 @@ class Config(object):
     ``strict_c``
         Whether or not the ``c`` object should throw an attribute error when
         access is attempted to an attribute that doesn't exist.
-    
     """
-    def __init__(self, myghty, map, paths, environ_config=None, default_charset='UTF-8',
-                 strict_c=False):
+    def __init__(self, myghty, map, paths, environ_config=None, 
+        default_charset='UTF-8', strict_c=False):
         if environ_config is None:
             environ_config = {}
         self.myghty = myghty
@@ -112,9 +111,9 @@ class Config(object):
             
             # Add old default as additional engine
             config.template_engines.append(old_default)
-        
         """
-        config = dict(engine=engine, template_root=root, template_options=options, alias=alias)
+        config = dict(engine=engine, template_root=root, 
+            template_options=options, alias=alias)
         self.template_engines.append(config)
     
     def init_app(self, global_conf, app_conf, package):
@@ -141,7 +140,6 @@ class Config(object):
             that into account.
         ``package``
             The name of the application package, to be stored in the app_conf.
-        
         """
         self.global_conf = global_conf
         self.app_conf = app_conf
@@ -166,19 +164,22 @@ class Config(object):
             errorware['debug'] = False
             errorware['error_email'] = global_conf.get('email_to')
             errorware['error_log'] = global_conf.get('error_log', None)
-            errorware['smtp_server'] = global_conf.get('smtp_server', 'localhost')
-            errorware['error_subject_prefix'] = global_conf.get('error_subject_prefix', 'WebApp Error: ')
+            errorware['smtp_server'] = global_conf.get('smtp_server', 
+                'localhost')
+            errorware['error_subject_prefix'] = global_conf.get(
+                'error_subject_prefix', 'WebApp Error: ')
             errorware['from_address'] = global_conf.get('from_address', 
-                                            global_conf.get('error_email_from', 'pylons@yourapp.com'))
-            errorware['error_message'] = global_conf.get('error_message', 'An internal server error occurred')
+                global_conf.get('error_email_from', 'pylons@yourapp.com'))
+            errorware['error_message'] = global_conf.get('error_message', 
+                'An internal server error occurred')
         
         # Standard Pylons configuration directives for Myghty
         myghty_defaults = {}
         
         # Raise a complete error for the error middleware to catch
         myghty_defaults['raise_error'] = True
-        myghty_defaults['component_root'] = [{os.path.basename(path): path} for \
-                                             path in self.paths['templates']]
+        myghty_defaults['component_root'] = [{os.path.basename(path): path} \
+            for path in self.paths['templates']]
         
         # Merge in the user-supplied Myghty values
         myghty_defaults.update(self.myghty)
@@ -187,15 +188,17 @@ class Config(object):
         myghty_defaults.setdefault('allow_globals', [])
                 
         myghty_defaults['allow_globals'].extend(
-            ['c', 'h', 's', 'session', 'request', 'params', 'g', 'render', 'render_fragment']
+            ['c', 'h', 's', '_', 'session', 'request', 'params', 'g', 'render',
+            'render_fragment']
         )
         
         self.myghty = myghty_defaults
         myghty_template_options = {}
-        if app_conf.get('cache_dir', False):
-            myghty_defaults['data_dir'] = os.path.join(app_conf['cache_dir'], 'templates')
-        else:
+        if 'myghty_data_dir' in app_conf:
             myghty_defaults['data_dir'] = app_conf['myghty_data_dir']
+        elif 'cache_dir' in app_conf:
+            myghty_defaults['data_dir'] = os.path.join(app_conf['cache_dir'], 
+                'templates')
         
         # Copy Myghty defaults and options into template options
         for k, v in self.myghty.iteritems():
@@ -205,10 +208,12 @@ class Config(object):
             if k.startswith('session_') or k.startswith('cache_'):
                 self.app_conf[k] = v
         
-        if not app_conf.has_key('session_data_dir'):
-            app_conf['session_data_dir'] = os.path.join(app_conf['cache_dir'], 'sessions')
-        if not app_conf.has_key('cache_data_dir'):
-            app_conf['cache_data_dir'] = os.path.join(app_conf['cache_dir'], 'cache')
+        if 'session_data_dir' not in app_conf:
+            app_conf['session_data_dir'] = os.path.join(app_conf['cache_dir'], 
+                'sessions')
+        if 'cache_data_dir' not in app_conf:
+            app_conf['cache_data_dir'] = os.path.join(app_conf['cache_dir'], 
+            'cache')
         
         # Prepare our default template engine
         self.add_template_engine('pylonsmyghty', None, myghty_template_options)
