@@ -3,6 +3,7 @@ import types
 import inspect
 import xmlrpclib
 
+from paste.httpexceptions import HTTPException
 from paste.deploy.config import CONFIG
 from paste.deploy.converters import asbool
 
@@ -29,7 +30,6 @@ class Controller(object):
     In the event that an action is not found to handle the request, the Controller
     will raise an "Action Not Found" error if in debug mode, otherwise a ``404 Not Found``
     error will be returned.
-    
     """
     __pudge_all__ = ['_inspect_call', '__call__', '_attach_locals']
     
@@ -39,7 +39,6 @@ class Controller(object):
         When debugging, the Pylons special objects are unavailable because they
         are thread locals. This function pulls the actual object and attaches it
         to the controller so that it can be examined for debugging purposes.
-        
         """
         self.c = pylons.c._current_obj()
         self.g = pylons.g._current_obj()
@@ -47,6 +46,7 @@ class Controller(object):
         self.session = pylons.session._current_obj()
         self.request = pylons.request._current_obj()
         self.buffet = pylons.buffet._current_obj()
+        self.start_response = None
     
     def _inspect_call(self, func, **kargs):
         """Calls a function with the Routes dict
@@ -56,38 +56,46 @@ class Controller(object):
         
         If the function has been decorated, it is assumed that the decorator
         preserved the function signature.
-        
         """
         argspec = inspect.getargspec(func)
-        kargs = self._req.environ['pylons.routes_dict'].copy()
+        req = pylons.request._current_obj()
+        kargs = req.environ['pylons.routes_dict'].copy()
+        kargs.update(dict(environ=req.environ, 
+            start_response=self.start_response))
         
         # @@ LEGACY: Add in ARGS alias to params
-        if self._req.environ.get('pylons.legacy'):
-            kargs['ARGS'] = self._req._legacy_params
+        if 'pylons.legacy' in req.environ:
+            kargs['ARGS'] = req._legacy_params
+        
+        # Hide the traceback for everything above this controller
+        __traceback_hide__ = 'before_and_this'
         
         c = pylons.c._current_obj()
         if argspec[2]:
-            for k,v in kargs.iteritems(): setattr(c, k, v)
+            for k, val in kargs.iteritems():
+                setattr(c, k, val)
             return func(**kargs)
         else:
             argnames = argspec[0][1:]
             args = []
             for name in argnames:
-                if kargs.has_key(name):
+                if name in kargs:
                     setattr(c, name, kargs[name])
                     args.append(kargs[name])
             return func(*args)
     
     def _dispatch_call(self):
         """Handles dispatching the request to the function"""
-        action = self._req.environ['pylons.routes_dict'].get('action')
+        req = pylons.request._current_obj()
+        action = req.environ['pylons.routes_dict'].get('action')
         action_method = action.replace('-', '_')
         func = getattr(self, action_method, None)
         if isinstance(func, types.MethodType):
             response = self._inspect_call(func)
         else:
             if asbool(CONFIG['global_conf'].get('debug')):
-                raise NotImplementedError('Action %s is not implemented' % action)
+                raise NotImplementedError(
+                    'Action %s is not implemented' % action)
             else:
                 response = pylons.Response(code=404)
         return response
@@ -97,18 +105,24 @@ class Controller(object):
         
         This is called when dispatched to as the Controller class docs explain
         more fully.
-        
         """
-        self._req = pylons.request._current_obj()
+        req = pylons.request._current_obj()
         
         # Keep private methods private
-        if self._req.environ['pylons.routes_dict'].get('action').startswith('_'):
+        if req.environ['pylons.routes_dict'].get('action', '').startswith('_'):
             return pylons.Response(code=404)
         
         if hasattr(self, '__before__'):
             self._inspect_call(self.__before__, **kargs)
-        response = self._dispatch_call()
-        if hasattr(self, '__after__'):
+
+        if not hasattr(self, '__after__'):
+            response = self._dispatch_call()
+        else:
+            try:
+                response = self._dispatch_call()
+            except HTTPException:
+                self._inspect_call(self.__after__)
+                raise
             self._inspect_call(self.__after__)
         return response
 
@@ -118,30 +132,34 @@ class WSGIController(Controller):
     This function works identically to the normal Controller, however it is called
     with the WSGI interface, and behaves as a WSGI application calling start_response
     and returning an iterable as content.
-    
     """
     def __call__(self, environ, start_response):
         self.start_response = start_response
-        match = environ['pylons.routes_dict']
-        self._req = pylons.request._current_obj()
         
         # Keep private methods private
-        if match.get('action').startswith('_'):
+        if environ['pylons.routes_dict'].get('action', '').startswith('_'):
             return pylons.Response(code=404)
         
         if hasattr(self, '__before__'):
             self._inspect_call(self.__before__)
-        response = self._dispatch_call()
-        if hasattr(self, '__after__'):
+
+        if not hasattr(self, '__after__'):
+            response = self._dispatch_call()
+        else:
+            try:
+                response = self._dispatch_call()
+            except HTTPException:
+                self._inspect_call(self.__after__)
+                raise
             self._inspect_call(self.__after__)
-        
+
         if hasattr(response, 'wsgi_response'):
             # Pull the content we need for a WSGI response
             status, response_headers, content = response.wsgi_response()
             start_response(status, response_headers)
         
             # Copy the response object into the testing vars if we're testing
-            if environ.get('paste.testing'):
+            if 'paste.testing' in environ:
                 environ['paste.testing_variables']['response'] = response
             response = content
         
@@ -152,42 +170,44 @@ class RPCController(Controller):
     resource = 'RPC2'
 
     def __call__(self, environ, start_response):
-
-
         self.start_response = start_response
         match = environ['pylons.routes_dict']
-        self._req = pylons.request._current_obj()
         
         # Keep private methods private
-        if match.get('action').startswith('_'):
+        if match.get('action', '').startswith('_'):
             return pylons.Response(code=404)
 
         if  match.get('action') != RPCController.resource:
             if environ['paste.config']['global_conf']['debug'] == 'false':
                 return pylons.Response(code=404)
             else:
-                raise NotImplementedError('RPCController only supports %s action', RPCController.resource) 
+                raise NotImplementedError(
+                    'RPCController only supports %s action', 
+                    RPCController.resource)
         
         if hasattr(self, '__before__'):
             self._inspect_call(self.__before__)
-        response = pylons.Response(xmlrpclib.dumps(( self._dispatch_call().wsgi_response()[2] ,)))
+        response = pylons.Response(
+            xmlrpclib.dumps(
+                (self._dispatch_call().wsgi_response()[2],)
+            )
+        )
         if hasattr(self, '__after__'):
             self._inspect_call(self.__after__)
         return response
-
-
     
     def __call__2(self, action, **kargs):
-        self._req = pylons.request._current_obj()
-        action = self._req.environ['pylons.routes_dict'].get('action')
+        req = pylons.request._current_obj()
+        action = req.environ['pylons.routes_dict'].get('action')
         action_method = action.replace('-', '_')
         if action_method != RPCController.resource:
             if asbool(CONFIG['global_conf'].get('debug')):
-                raise NotImplementedError('RPCController only supports %s action',
-                                          RPCController.resource)
+                raise NotImplementedError(
+                    'RPCController only supports %s action',
+                    RPCController.resource)
             else:
                 return pylons.Response(code=404)
-        d = self._req.environ['wsgi.input'].read()
+        d = req.environ['wsgi.input'].read()
         params, method = xmlrpclib.loads(d)
         
         if hasattr(self, '__before__'):
