@@ -1,8 +1,8 @@
 """Provides convenient access to an SQLObject-managed database.
 
-This module enables easy use of an SQLObject database by providing an auto-connect
-hub that will utilize the db uri string given in the Paste conf file called
-``sqlobject.dburi``
+This module enables easy use of an SQLObject database by providing an 
+auto-connect hub that will utilize the db uri string given in the Paste conf
+file called ``sqlobject.dburi``.
 
 It is based heavily (if not 99%) on the TurboGears file of the same name.
 """
@@ -21,13 +21,11 @@ class AutoConnectHub(ConnectionHub):
     
     def __init__(self, uri=None):
         if not uri:
-            conf = CONFIG.current_conf()
-            appconf = conf.get('app_conf', conf.get('app'))
-            uri = appconf.get('sqlobject.dburi')
+            uri = CONFIG['app_conf'].get('sqlobject.dburi')
         self.uri = uri
         ConnectionHub.__init__(self)
     
-    def getConnection(self):
+    def get_connection(self):
         try:
             conn = self.threadingLocal.connection
             return conn
@@ -47,15 +45,10 @@ class AutoConnectHub(ConnectionHub):
                 raise AttributeError(
                     "No connection has been defined for this thread "
                     "or process")
-
-    def reset(self):
-        """Used for testing purposes. This drops all of the connections
-        that are being held."""
-        self.threadingLocal = threading_local()
-        
+    
     def begin(self):
         """Starts a transaction."""
-        conn = self.getConnection()
+        conn = self.get_connection()
         if isinstance(conn, Transaction):
             if conn._obsolete:
                 conn.begin()
@@ -93,7 +86,7 @@ _hubs = dict()
 class PackageHub(object):
     """Transparently proxies to an AutoConnectHub for the URI
     that is appropriate for this package. A package URI is
-    configured via "packagename.dburi" in the global CherryPy
+    configured via "packagename.dburi" in the Paste ini file
     settings. If there is no package DB URI configured, the
     default (provided by "sqlobject.dburi") is used.
     
@@ -123,17 +116,16 @@ class PackageHub(object):
     def set_hub(self):
         dburi = self.dburi
         if not dburi:
-            conf = CONFIG.current_conf()
-            appconf = conf.get('app_conf', conf.get('app'))
-            dburi = appconf.get("%s.dburi" % self.packagename, None)
+            appconf = CONFIG['app_conf']
+            dburi = appconf.get("%s.dburi" % self.packagename)
             if not dburi:
-                dburi = appconf.get("sqlobject.dburi", None)
+                dburi = appconf.get("sqlobject.dburi")
         if not dburi:
             raise KeyError, "No database configuration found!"
-        hub = _hubs.get(dburi, None)
+        hub = _hubs.get(dburi)
         if not hub:
             hub = AutoConnectHub(dburi)
             _hubs[dburi] = hub
         self.hub = hub
             
-__all__ = ["PackageHub", "AutoConnectHub"]
\ No newline at end of file
+__all__ = ["PackageHub", "AutoConnectHub"]
