@@ -5,13 +5,9 @@ The util module provides the main Helper object used by Pylons.
 PylonsTemplate is a Paste Template sub-class that configures the source
 directory and default plug-ins for a new Pylons project.
 """
-import gettext
 import os.path
-import sys
-import warnings
 from paste.deploy.config import CONFIG
 from paste.script.templates import Template
-from routes import threadinglocal
 import pylons
 
 def log(msg):
@@ -26,20 +22,17 @@ def _(value):
     .. code-block:: Python
     
         h._('This should be in lots of languages')
-    
     """
     return pylons.translator['translator'].gettext(value)
 
 def set_lang(lang):
     """Set the language used"""
-    project_name = CONFIG['app_conf']['package']
-    pylons.translator['lang'] = lang
     if lang is None:
         pylons.translator['translator'] = _Translator()
     else:
-        from pkg_resources import resource_string, resource_stream, \
-            resource_exists, resource_filename
+        from pkg_resources import resource_exists
         from pylons.i18n.translation import egg_translation
+        project_name = CONFIG['app_conf']['package']
         catalog_path = os.path.join('i18n', lang, 'LC_MESSAGES')
         if not resource_exists(project_name, catalog_path):
             raise LanguageError('Language catalog %s not found' % \
@@ -48,10 +41,10 @@ def set_lang(lang):
             egg_translation(project_name, lang=catalog_path)
 
 def get_lang():
-    return pylons.translator['lang']
+    return pylons.translator.get('lang')
 
 def get_prefix(environ):
-    if environ.has_key('paste.config'):
+    if 'paste.config' in environ:
         prefix = environ['paste.config']['app_conf'].get('prefix', '')
     else:
         # Not ideal but if the error occurs before the paste.config is available not a lot we can do
@@ -74,7 +67,6 @@ def class_name_from_module_name(module_name):
         'WithUnderscores'
         >>> class_name_from_module_name('oneword')
         'Oneword'
-    
     """
     words = module_name.replace('-', '_').split('_')
     return ''.join([w.title() for w in words])
@@ -102,49 +94,17 @@ class _Translator(object):
     def gettext(self, value):
         return value
 
-class Helpers(object):
-    def __init__(self, **opts):
-        pass
-    
-    def __getattr__(self, name):
-        if hasattr(pylons.request._oldh, name):
-            return getattr(pylons.request._oldh, name)
-        elif hasattr(pylons.request, '_h') and hasattr(pylons.request._h, name):
-            return getattr(pylons.request._h, name)
-        elif name in pylons.translator:
-            if name == 'lang':
-                warnings.warn('Getting the translator language via h.lang is '
-                              'deprecated: Please use h.get_lang() instead',
-                              DeprecationWarning, 2)
-            return pylons.translator[name]
-        else:
-            raise AttributeError("No such helper: '%s'" % repr(name))
-    
-    def __setattr__(self, name, value):
-        if name != 'lang':
-            raise AttributeError('Helper attributes cannot be set, except for '
-                                 "the special 'lang' attribute. Use the "
-                                 "context object 'c' to store context data.")
-        else:
-            warnings.warn("Setting the translator language via h.lang = '%s' is "
-                          "deprecated: Please use h.set_lang('%s') instead" % \
-                          (value, value), DeprecationWarning, 2)
-            self.set_lang(value)
-    
-    def translate(self, value):
-        """Deprecated, use _()"""
-        raise NotImplementedError('Use h._() instead')
-    
-    log = staticmethod(log)
-    _ = staticmethod(_)
-    set_lang = staticmethod(set_lang)
-    get_lang = staticmethod(get_lang)
-
 class PylonsTemplate(Template):
-    _template_dir = 'templates/paster_template'
+    _template_dir = 'templates/default_project'
     summary = 'Pylons application template'
     egg_plugins = ['Pylons', 'WebHelpers']
 
+class MinimalPylonsTemplate(Template):
+    _template_dir = 'templates/minimal_project'
+    summary = 'Pylons minimal application template'
+    egg_plugins = ['Pylons', 'WebHelpers']
+    
+
 __all__ = ['AttribSafeContextObj', 'ContextObj', 'Helpers', 'class_name_from_module_name',
     'log', '_', 'set_lang', 'get_lang']
 __pudge_all__ = __all__ + ['PylonsTemplate']
