@@ -3,7 +3,6 @@
 This module is responsible for creating the basic Pylons WSGI application. It's generally
 assumed that it will be called by Paste, though any WSGI application server could create
 and call the WSGI app as well.
-
 """
 import sys
 import re
@@ -19,9 +18,7 @@ from paste.wsgiwrappers import WSGIRequest
 from routes import request_config
 
 import pylons
-import pylons.templating
-import pylons.legacy
-from pylons.util import ContextObj, AttribSafeContextObj, _Translator, class_name_from_module_name
+from pylons.util import ContextObj, AttribSafeContextObj, _Translator, set_lang, class_name_from_module_name
 from pylons.controllers import Controller, WSGIController
 
 class PylonsBaseWSGIApp(object):
@@ -39,10 +36,17 @@ class PylonsBaseWSGIApp(object):
     
     Resolving the URL and dispatching can be customized by sub-classing or
     "monkey-patching" this class. Subclassing is the preferred approach.
-    
     """
-    def __init__(self, mapper, package_name, globals, default_charset=None):
+    def __init__(self, mapper, package_name, globals, 
+                 helpers=None, default_charset=None):
+        """Initialize a base Pylons WSGI application
+        
+        The base Pylons WSGI application requires several keywords, if no 
+        helpers reference is given, a legacy warning will be raised and it
+        will attempt to search the project for a helpers.py module.
+        """
         self.mapper = mapper
+        self.helpers = helpers
         self.globals = globals
         self.package_name = package_name
         config = globals.pylons_config
@@ -79,10 +83,10 @@ class PylonsBaseWSGIApp(object):
         # parsing POST unless absolutely necessary.
         req = pylons.request._current_obj()
         old_method = None
-        if '_method' in environ['QUERY_STRING'] and req.GET.has_key('_method'):
+        if '_method' in environ.get('QUERY_STRING', '') and '_method' in req.GET:
             old_method = environ['REQUEST_METHOD']
             environ['REQUEST_METHOD'] = req.GET['_method']
-        elif environ['REQUEST_METHOD'] == 'POST' and req.POST.has_key('_method'):
+        elif environ['REQUEST_METHOD'] == 'POST' and '_method' in req.POST:
             old_method = environ['REQUEST_METHOD']
             environ['REQUEST_METHOD'] = req.POST['_method']
         
@@ -107,7 +111,16 @@ class PylonsBaseWSGIApp(object):
             resp = pylons.legacy.response
             if hasattr(pylons.legacy.response, 'wsgicall'):
                 # Legacy app using run_wsgi
+                warnings.warn(
+                    "Using run_wsgi is deprecated. You should use return "
+                    "wsgiapp(request.environ, self.start_response) instead. ",
+                    DeprecationWarning, 2)
                 return resp.content
+            warnings.warn(
+                "Running in legacy mode, ensure that your controller actions "
+                "are returning a Pylons Response and not using the 'm' object "
+                "as it has been deprecated.",
+                DeprecationWarning, 2)
             status, response_headers, content = resp.wsgi_response()
             start_response(status, response_headers)
             return content
@@ -118,35 +131,15 @@ class PylonsBaseWSGIApp(object):
         """Setup and register all the Pylons objects with the registry"""
         req = WSGIRequest(environ)
         
-        # This is a legacy test for pre-0.9.2 projects to continue using the old
-        # style Helper. New style directly uses the projects lib.helpers module
-        # for 'normal' Python import usage with no surprises.
-        __import__(self.package_name + '.lib.base')
-        their_h = getattr(sys.modules[self.package_name + '.lib.base'], 'h', None)
-
-        try: 
-            helpers_name = self.package_name + '.config.helpers' 
-            __import__(helpers_name) 
-        except: 
-            helpers_name = self.package_name + '.lib.helpers' 
-            __import__(helpers_name)
-        if their_h != pylons.h and their_h is not None:
-            # We're using the new Helper import style
-            req._h = sys.modules[helpers_name]
-        else:
-            # We still need to keep a reference to their helpers for the old
-            # Helpers object.
-            req._oldh = sys.modules[helpers_name]
+        helpers = self.helpers or pylons.legacy.load_h(self.package_name)
+        environ['paste.registry'].register(pylons.h, helpers)
         
         # Setup the translator global object
         trans = dict(translator=_Translator())
         trans['CONFIG'] = dict(app_conf=self.globals.pylons_config.app_conf,
             global_conf=self.globals.pylons_config.global_conf)
-        if self.globals.pylons_config.app_conf.has_key('lang'):
-            trans['translator'](self.globals.pylons_config.app_conf['lang'])
-        else:
-            trans['lang'] = None
         environ['paste.registry'].register(pylons.translator, trans)
+        set_lang(self.globals.pylons_config.app_conf.get('lang'))
         
         # Setup the basic pylons global objects
         environ['paste.registry'].register(paste.wsgiwrappers.settings, self.settings)
@@ -164,7 +157,7 @@ class PylonsBaseWSGIApp(object):
             req._legacy_params = req.params.mixed()
             environ['paste.registry'].register(pylons.legacy.response, WSGIResponse())
             environ['paste.registry'].register(pylons.m, 
-                pylons.legacy.Myghty_Compat(environ, start_response))
+                pylons.legacy.MyghtyCompat(environ, start_response))
             environ['paste.registry'].register(pylons.params, req._legacy_params)
         
         econf = environ['pylons.environ_config']
@@ -193,6 +186,9 @@ class PylonsBaseWSGIApp(object):
         full_module_name = self.package_name + '.controllers.' \
             + controller.replace('/', '.')
         
+        # Hide the traceback here if the import fails (bad syntax and such)
+        __traceback_hide__ = 'before_and_this'
+        
         __import__(full_module_name)
         module_name = controller.split('/')[-1]
         class_name = class_name_from_module_name(module_name) + 'Controller'
@@ -268,9 +264,8 @@ class PylonsApp(object):
     in the config object by supplying other keys to look for in the environ
     where objects for the session/cache will be. If they're set to none,
     then no session/cache objects will be available.
-    
     """
-    def __init__(self, config, default_charset=None):
+    def __init__(self, config, default_charset=None, helpers=None, g=None):
         self.config = config
         if default_charset:
             warnings.warn(
@@ -281,28 +276,45 @@ class PylonsApp(object):
                 "default_charset='%s')" % default_charset, DeprecationWarning, 2)
             self.config.default_charset = default_charset
 
-        g = None
-        try:
-            package = __import__(config.package + '.lib.app_globals', globals(), locals(), ['Globals'])
-        except ImportError:
-            pass
-        else:
-            g = package.Globals(config.global_conf, config.app_conf, config=config)
+        if not g:
+            warnings.warn(
+                "Having the 'g' object load from a default app_globals module "
+                "is deprecated. Please update your middleware.py with:\n\n"
+                "    import MYPROJ.lib.app_globals as app_globals\n"
+                "    import MYPROJ.lib.helpers\n\n"
+                "where MYPROJ is the name of your project.\n"
+                "Then edit the PylonsApp instantiation with:\n\n"
+                "    app = pylons.wsgiapp.PylonsApp(\n"
+                "        config, \n"
+                "        helpers=MYPROJ.lib.helpers, \n"
+                "        g=app_globals.Globals\n"
+                "    )\n\n",
+                DeprecationWarning, 2)
+            try:
+                globals_package = __import__(config.package + '.lib.app_globals', globals(), locals(), ['Globals'])
+                g = getattr(globals_package, 'Globals')
+            except ImportError:
+                pass
+        if not g:
+            # Assign a default globals object
+            g = type("Globals", (), {})
+        if g:
+            g = g(config.global_conf, config.app_conf, config=config)
             g.pylons_config = config
         
         # Create the base Pylons wsgi app
-        app = PylonsBaseWSGIApp(config.map, config.package, g)
+        app = PylonsBaseWSGIApp(config.map, config.package, g, helpers=helpers)
         
         # Pull user-specified environ overrides, or just setup default
         # session and caching objects
         self.econf = econf = config.environ_config.copy()
-        if not econf.has_key('session'):
+        if 'session' not in econf:
             from beaker.session import SessionMiddleware
             econf['session'] = 'beaker.session'
             app = SessionMiddleware(app, config.global_conf, 
                 auto_register=True, **config.app_conf)
         
-        if not econf.has_key('cache'):
+        if 'cache' not in econf:
             from beaker.cache import CacheMiddleware
             econf['cache'] = 'beaker.cache'
             app = CacheMiddleware(app, config.global_conf, **config.app_conf)
@@ -319,7 +331,8 @@ WSGIResponse = None
 class LegacyApp(object):
     def __init__(self, config):
         global WSGIResponse
-        from paste.wsgiwrappers import WSGIResponse
+        from paste.wsgiwrappers import WSGIResponse as WResponse
+        WSGIResponse = WResponse
         self.app = PylonsApp(config)
         self.globals = self.app.globals
     
@@ -331,7 +344,7 @@ def make_app(config):
     """ Legacy WSGI app creator"""
     warnings.warn(
         "Legacy WSGI app in use for pre-0.9 application. This will be "
-        "removed at some point post-1.0 which will require minor updates "
+        "removed before the release of 1.0 which will require minor updates "
         "to your application.",
         DeprecationWarning, 2)
     papp = LegacyApp(config)
