@@ -37,13 +37,13 @@ def svn_repos_setup():
 def paster_create():
     global projenv
     sys.stderr.write(' '.join(['paster', 'create', '--verbose', '--no-interactive',
-                      '--svn-repository=' + testenv.svn_url,
+                      #'--svn-repository=' + testenv.svn_url,
                       '--template=pylons',
                       'ProjectName',
                       'version=0.1',
                       ]))
     res = testenv.run(_get_script_name('paster'), 'create', '--verbose', '--no-interactive',
-                      '--svn-repository=' + testenv.svn_url,
+                      #'--svn-repository=' + testenv.svn_url,
                       '--template=pylons',
                       'ProjectName',
                       'version=0.1',
@@ -69,7 +69,7 @@ def paster_create():
     testenv.run(_get_script_name('python')+' setup.py egg_info',
                 cwd=os.path.join(testenv.cwd, 'ProjectName').replace('\\','/'),
                 expect_stderr=True)
-    testenv.run(_get_script_name('svn'), 'commit', '-m', 'Created project', 'ProjectName')
+    #testenv.run(_get_script_name('svn'), 'commit', '-m', 'Created project', 'ProjectName')
     # A new environment with a new
     projenv = TestFileEnvironment(
         os.path.join(testenv.base_path, 'ProjectName').replace('\\','/'),
@@ -84,19 +84,21 @@ def make_controller():
     res = projenv.run(_get_script_name('paster')+' controller sample')
     assert os.path.join('projectname','controllers','sample.py') in res.files_created
     assert os.path.join('projectname','tests','functional','test_sample.py') in res.files_created
-    res = projenv.run(_get_script_name('svn')+' status')
+    #res = projenv.run(_get_script_name('svn')+' status')
     # Make sure all files are added to the repository:
     assert '?' not in res.stdout
 
-def _do_proj_test(copydict, emptyfiles=[]):
+def _do_proj_test(copydict, emptyfiles=None):
     """Given a dict of files, where the key is a filename in test_files, the value is
     the destination in the new projects dir. emptyfiles is a list of files that should
     be created and empty."""
+    if not emptyfiles:
+        emptyfiles = []
     for original, newfile in copydict.iteritems():
         projenv.writefile(newfile, frompath=original)
     for fi in emptyfiles:
         projenv.writefile(fi)
-    res = projenv.run(_get_script_name('nosetests')+' projectname/tests',
+    res = projenv.run(_get_script_name('nosetests'),
                       expect_stderr=True,
                       cwd=os.path.join(testenv.cwd, 'ProjectName').replace('\\','/'))
 
@@ -131,6 +133,36 @@ def do_two_engines():
 def do_crazy_decorators():
     _do_proj_test({'functional_sample_controller_sample4.py':'projectname/tests/functional/test_sample3.py'})
 
+def do_cheetah():
+    copydict = {
+        'controller_sample.py':'projectname/controllers/sample.py',
+        'testcheetah.tmpl':'projectname/cheetah/testcheetah.tmpl',
+        'middleware_cheetah_engine.py':'projectname/config/middleware.py',
+        'functional_sample_controller_cheetah.py':'projectname/tests/functional/test_cheetah.py',
+    }
+    empty = [
+         'projectname/cheetah/__init__.py',
+         'projectname/tests/functional/test_sample.py',
+         'projectname/tests/functional/test_sample2.py',
+         'projectname/tests/functional/test_sample3.py'
+     ]
+    _do_proj_test(copydict, empty)
+
+def do_cache_decorator():
+    copydict = {
+        'middleware_def_engine.py':'projectname/config/middleware.py',
+        'app_globals.py':'projectname/lib/app_globals.py',
+        'cache_controller.py':'projectname/controllers/cache.py',
+        'functional_controller_cache_decorator.py':'projectname/tests/functional/test_cache.py',
+    }
+    empty = [
+        'projectname/tests/functional/test_cheetah.py',
+        'projectname/tests/functional/test_sample.py',
+        'projectname/tests/functional/test_sample2.py',
+        'projectname/tests/functional/test_sample3.py'
+     ]
+    _do_proj_test(copydict, empty)
+
 def do_legacy_app():
     legacyenv = TestFileEnvironment(
         os.path.join(testenv.base_path, 'legacyapp').replace('\\','/'),
@@ -144,9 +176,9 @@ def do_legacy_app():
 
 def make_tag():
     global tagenv
-    res = projenv.run(_get_script_name('svn')+' commit -m "updates"')
+    #res = projenv.run(_get_script_name('svn')+' commit -m "updates"')
     # Space at the end needed so run() doesn't add \n causing svntag to complain
-    res = projenv.run(_get_script_name('python')+' setup.py svntag --version=0.5 ')
+    #res = projenv.run(_get_script_name('python')+' setup.py svntag --version=0.5 ')
     # XXX Still fails => setuptools problem on win32?
     assert 'Tagging 0.5 version' in res.stdout
     assert 'Auto-update of version strings' in res.stdout
@@ -161,14 +193,16 @@ def make_tag():
         template_path=template_path)
 
 def test_project():
-    yield svn_repos_setup
+    #yield svn_repos_setup
     yield paster_create
     yield make_controller
     yield do_pytest
     yield do_test_known
     yield do_kid_default
     yield do_two_engines
+    yield do_cheetah
     yield do_crazy_decorators
+    yield do_cache_decorator
     #yield do_legacy_app
     #yield make_tag
     
